# Hello World

[![Build Status](https://travis-ci.com/nikhar1210/helloworld_PyPI.svg?branch=main)](https://travis-ci.com/nikhar1210/helloworld_PyPI)

This is an example project demonstrating how to publish a python module tp PyPI


## Installation

Run the following to install:

```python
pip install helloworld-nik12
```

## Usage

```python

from helloworld import say_hello

# Generate hello world
say_hello(name=None)

#Generate "Hello, Joe!"
say_hello("Joe")

```